# Fetch Staking ERC20 Contract

## Description

This contract package is used to interface with a Fetch staking ERC20 contract.

## Functions

* `get_stake(address)`: Get the balance for a specific `address`